#!/usr/bin/perl
# +========================================================================+
# || CAT CipUX Administration Tool                                        ||
# || Webmin module: transferadmin.cgi                                        ||
# || for administration of CAT and CipUX                                  ||
# || (c) 2001,2002,2003,2005 by Christian Kuelker                         ||
# || License: GPLv2                                                       ||
# +========================================================================+

package transferadmin_cgi;

do '../web-lib.pl';
&init_config();

use CipUX::CiBot;
use CipUX::Cat;
use CipUX::Task;

my $BRAND    = "cipworx";
my $PROJECT  = "cipux";
my $SCRIPT   = "transferadmin.cgi";


&log($SCRIPT,"="x76);
&cibot_get_ldap_config();
&log($SCRIPT,"- remote user [$remote_user]");

my ($result,$role) = &cibot_acl($SCRIPT,$remote_user);
&cat_header($remote_user,\&header,\&help_search_link,\&text);

# hostname, user, arrayref
print &cat_status_line(&get_system_hostname(),
                       "$remote_user ($role) -> $result",
		       [
			&text('server'),
			&text('status'),
			$cipux{Customer},
			&text('date'),
			&text('version')
		       ]
		      );

# +=======================================================================+
# ||  CAT ACL check                                                      ||
# +=======================================================================+
if($result ne 'ok'){
  print "<h1>".&text('access_denied')."</h1>";
  my $error = &text('access_denied_explanation',
                   "<b>$remote_user</b>",
                   "<b>$role</b>");
  &log($SCRIPT,$error);
  print &cat_error($error);
  &cat_footer($remote_user,\&footer,$ldap{CipUX}{Cipux_Support});
  exit(0)
}

# +=======================================================================+
# || Environment                                                         ||
# +=======================================================================+
&log($SCRIPT,"ReadParse...");
ReadParse();# webmin

#my $system = $in{'system'} if defined($in{'system'});# system

foreach(sort keys %in){
  &log($SCRIPT,"- IN: [$_] = [$in{$_}]") if defined($in{$_});
}

my %roles = ();
my @roles = `cipux_task_list_roles`;
foreach(@roles){chomp;$roles{$_}=1}

# =========================================================================+
#                    Config                                               ||
# =========================================================================+
if(defined($in{change_cipux_variable})
   and defined($in{system})
   and defined($in{cipux_variable})
   and defined($in{cipux_variable_value})){
   &log($SCRIPT,"* change_cipux_variable");

  # for cipadmin GUI
  $in{cipux_variable_value}=1 if $in{cipux_variable_value} eq 'enabled';
  $in{cipux_variable_value}=0 if $in{cipux_variable_value} eq 'disabled';

  if($in{cipux_variable} =~ m/Acl/){
    &log($SCRIPT,"- check given ACL [$in{cipux_variable_value}]");

    $in{cipux_variable_value} =~ s/^\s+//g;
    $in{cipux_variable_value} =~ s/\s+$//g;

    # $#i > 0  (i = input)
    my @i = split(/\s+/,$in{cipux_variable_value});
    &log($SCRIPT,"- array length [$#i]");

    # $#i == 0
    push(@i,$in{cipux_variable_value}) if $#i == 0; # one element
    # $#i < 0
    push(@i,'') if $#a == -1; # undef -> def

    # MATCHING = grep { TEST ($_) } @LIST;
    my @matching = grep { $roles{$_} } @i;

    foreach(keys %roles){
      &log($SCRIPT,"- roles  [$_]");
    }
    foreach (@matching){
      &log($SCRIPT,"- matching  [$_]");
    }
    my %seen = ();
    my @uniqu = grep { ! $seen{$_} ++ } @matching;
    foreach (@uniqu){
      &log($SCRIPT,"- u  [$_]");
    }
    $in{cipux_variable_value}='';
    $in{cipux_variable_value}=join(' ',@uniqu);
    &log($SCRIPT,"- write  [$in{cipux_variable_value}]");
  }
  my $value = "$in{cipux_variable}=$in{cipux_variable_value}";
  &cipux_task_change_cipux_config_variable_value('cgi',$in{system},$value);
}

#my $group_href = &cibot_list('X','cipux');# list all group's gidNumber

# only in this CGI!
&cibot_get_cipux_config("/etc/cipux/cipux.conf");

# this in every CGI, where it is ok
&cibot_get_ldap_config();

# =========================================================================+
# ||                         Main                                         ||
# =========================================================================+
print "<h2>".&text('cipux_configuration')." ($remote_user as $role)</h2>";


  print &cat_table_header(2,$tb,&text('cipux_configuration').": $system");
  print &cat_table_row([1,1],
		       [$tb,$tb],
		       [
		         &text('login'),
		         &text('action')]);

  my @account = `cipux_task_list_users`;
  my @courses = `cipux_task_list_courses`;
  my @choice = qw(transfered repeat leave);
  my %choice ={};
  foreach(@choice){$choice{$_}=1;}
  push(@choice,@courses);
  foreach my $uid (@account){
      chomp($uid);

      #push(@choice,@courses);
      my $choice = "<form method=post action='transferadmin.cgi'>";
      $choice .= "<input type=hidden name=cipux_variable value=\"$variable\" >";
      $choice .= "<input type=hidden name=system value=\"CAT\" >";

      $choice   .= " <select name='cipux_variable_value' size=1>";
      foreach (@choice){
        if($_ eq "transfered"){
          $choice .= "<option selected value='$_'>".&text($_)."</option>\n";
        }elsif(defined $seen{$_}){
          $choice .= "<option value='$_'>".&text($_)."</option>\n";
        }else{
          $choice .= "<option value='$_'>$_</option>\n";
        }
      }
      $choice  .= "</select>";
      $choice  .= "</form>\n";
      print &cat_table_row([1,0],
			   ['',$cb],
			   [$uid,$choice]
			  );
    }
 print &cat_table_footer ."<br>";
 print  "<input type=submit name=change_cipux_variable value=\"".&text('save')."\"> ";

    #  print "</from>";

# +=======================================================================+
# || Footer                                                              ||
# +=======================================================================+
&cat_footer($remote_user,\&footer,$ldap{CipUX}{Cipux_Support});

exit(0);

