#!/usr/bin/perl -w
# +=======================================================================+
# || cipux_maint_diagnostic                                              ||
# ||                                                                     ||
# || This script runs several tests against  Test.pm and tries to        ||
# || check if the CipUX installation is ok.                              ||
# ||                                                                     ||
# ||                                                                     ||
# || (c) 2005 Christian Kuelker                                          ||
# ||                                                                     ||
# || License: GPLv2 (GPL version 2 or later)                             ||
# ||                                                                     ||
# +=======================================================================+

use Test;
use strict;

my $cipux_conf = "/etc/cipux/cipux.conf";
my $cipux_schema = "/etc/ldap/schema/cipux.schema";

my $pre = shift;

BEGIN { plan tests => 35 }

print "# This script will test the CipUX installation.\n";
print "# If somthing is not ok, follow the instruction in brackets: [...] if any\n";
print "#\n";
print "# Test:\n";

# 01
print "# [01]: exsists /etc/cipux? => ";
exit(1) if not ok(-d "/etc/cipux");# [please install all packages or copy the folder from an instelled CipUX]

# 02
my $mode = (stat("/etc/cipux"))[2];
my $hmode = sprintf "%04o", $mode & 07777;
print "# [02]:  /etc/cipux has the mode $hmode, is this equal to 750? =>";
exit(1) if not ok( "0750" eq $hmode); # [please execute: chmod 750  /etc/cipux]

# 03
print "# [03]: exsists /var/log/cipux? => ";
exit(1) if not ok(-d "/var/log/cipux");# [please install all packages or copy the folder from an instelled CipUX]

# 04
$mode = (stat("/var/log/cipux"))[2];
$hmode = sprintf "%04o", $mode & 07777;
print "# [04]: /var/log/cipux has the mode $hmode, is this equal to 750? =>";
exit(1) if not ok( "0750" eq $hmode); # [please execute: chmod 750  /var/log/cipux]

# 05
print "# [05]: exists  $cipux_conf? => ";
exit(1) if not ok(-e $cipux_conf); # [please install the cipux-cibot package!]

# 06
print "# [06]: is it readable? => ";
exit(1) if not ok(-r $cipux_conf); # [please install the cipux-cibot package!]

# 07
print "# [07]: is the Ldap_Password set? => ";
my $set_pwd     = `grep Ldap_Password $cipux_conf`;
chomp($set_pwd);
my $default_pwd = "Ldap_Password=secret";
exit(1) if not ok($set_pwd ne $default_pwd);# [please set the correct root password at Ldap_Password in $cipux_conf]

# 08
print "# [08]: existse $cipux_schema? => ";
exit(1) if not ok(-e $cipux_schema); # [please install the cipux-common package!]

# 09
my $include = `grep $cipux_schema /etc/ldap/slapd.conf`;
print "# [09]: is the cipux.schema in slapd.conf included? => ";
exit(1) if not ok($include ne "");# [please edit /etc/ldap/slapd.conf and add the line: include /etc/ldap/schema/cipux.schema ]

# 10
my $slapd = `ps ax|grep slapd|grep -v grep`;
print "# [10]: is the LDAP server running? => ";
exit(1) if not ok($slapd); # [ please start slapd: /etc/init.d/slapd start ]

# 11
my $password = `grep Ldap_Password /etc/cipux/cipux.conf`;
chomp($password);
$password =~ s/ //g;
$password =~ s/Ldap_Password=//g;

# 11
print "# [11]: can we browse the ldap server? => ";
my $cmd1 ="/usr/bin/ldapsearch -x -p 389 -h localhost -b 'uid=root,ou=People,dc=skole,dc=skolelinux,dc=no' -LLL uid uid=root";
my @root1 = `$cmd1`;
chomp($root1[1]);
my $root1 = $root1[1];

if(ok($root1 eq "uid: root")){

}else{
   print "# ERROR: we can not browse the LDAP with password '$password'!\n";
   print "cmd [$cmd1]\n";
   foreach (@root1){
     chomp();
     print "# * [$_]\n";
   }
   exit(1);
}

# 12
print "# [12]: can we access the ldap server by password? => ";
my $cmd2 ="/usr/bin/ldapsearch -x -p 389 -h localhost -ZZ -w '$password' -D 'cn=admin,ou=People,dc=skole,dc=skolelinux,dc=no' -b 'uid=root,ou=People,dc=skole,dc=skolelinux,dc=no' -LLL uid uid=root";
my @root2 = `$cmd2`;
chomp($root2[1]);
my $root2 = $root2[1];
if(ok($root2 eq "uid: root")){

}else{
   print "# ERROR: we can not access the LDAP with password '$password'!\n";
   print "cmd [$cmd2]\n";
   foreach (@root2){
     chomp();
     print "# * [$_]\n";
   }
   exit(1);
}


exit (0)  if defined($pre);

# 13
my @modules = qw(CipUX::CiBot CipUX::Task CipUX::Conversion CipUX::Cat);
my $test = 13;
foreach my $m (@modules){
  print "# [$test]: do the module '$m' load without warnings? => ";
  $test++;
  my $load = `perl -e 'use $m;' 2>&1`;
  print "\n# ERROR: $load\n" if $load ne "";
  exit(1) if not ok($load eq ""); # [install a new version of the module!]
}

# 17
print "# [$test]: do the CipUX::CiBot module load with require at once? => ";
exit(1) if not ok(eval("require CipUX::CiBot;")); # [please install an new version of cipux-cibot!]
$test++;

# 18
print "# [$test]: do the CipUX::Cat module load with require at once? => ";
exit(1) if not ok(eval("require CipUX::Cat;")); # [please install an new version of cipux-cat-webmin!]
$test++;

# 19
print "# [$test]: do the CipUX::Task module load with require at once? => ";
exit(1) if not ok(eval("require CipUX::Task;")); # [please install an new version of cipux-cibot!]
$test++;

# 20
print "# [$test]: do the CipUX::Conversion module load with require at once? => ";
exit(1) if not ok(eval("require CipUX::Conversion;")); # [please install an new version of cipux-cibot!]
$test++;

# 21
print "# [$test]: is the cipux_task_list_users script installed? => ";
exit(1) if not ok(-e "/usr/bin/cipux_task_list_users");
$test++;

# 22
print "# [$test]: is the cipux_task_list_users script executable? => ";
exit(1) if not ok(-x "/usr/bin/cipux_task_list_users");
$test++;

# 23
print "# [$test]: get we some ouput? => ";
my @userlist = `/usr/bin/cipux_task_list_users`;
exit(1) if not ok($#userlist > -1); # [ there are no CipUX users in LDAP, the cipux_setup_ldap_objects script should have failed]
$test++;


my %userlist = ();
foreach my $u (@userlist){
  chomp($u);
  $userlist{$u}=1;
  print "# * USER: $u\n";
}

# 24
print "# [$test]: is the user object 'cipadmin' there? =>";
exit(1) if not ok($userlist{cipadmin}); # [ the account cipadmin is not there, the cipux_setup_ldap_objects script should have failed. create account cipadmin!]
$test++;

# 25
print "# [$test]: is the cipux_task_list_courses script installed? => ";
exit(1) if not ok(-e "/usr/bin/cipux_task_list_courses");
$test++;

# 26
print "# [$test]: is the cipux_task_list_courses script executable? => ";
exit(1) if not ok(-x "/usr/bin/cipux_task_list_courses");
$test++;

###
### There are no default courses
###

#print "# * get we some ouput? => ";
#my @courselist = `/usr/bin/cipux_task_list_courses`;
#exit(1) if not ok($#userlist > 0);

#my %courselist = ();
#foreach my $c (@courselist){
#  chomp($c);
#  $courselist{$c}=1;
#  print "# * COURSE: $c\n";
#}

# 27
print "# [$test]: is the cipux_task_list_roles script installed? => ";
exit(1) if not ok(-e "/usr/bin/cipux_task_list_roles");
$test++;

# 28
print "# [$test]: is the cipux_task_list_roles script executable? => ";
exit(1) if not ok(-x "/usr/bin/cipux_task_list_roles");
$test++;

# 29
print "# [$test]: get we some ouput? => ";
my @roleslist = `/usr/bin/cipux_task_list_roles`;
exit(1) if not ok($#roleslist > 0);
$test++;

my %roleslist = ();
foreach my $r (@roleslist){
  chomp($r);
  $roleslist{$r}=1;
  print "# * ROLE: $r\n";
}

# 30
print "# [$test]: is the role object assistent there? => ";
exit(1) if not ok($roleslist{assistent}); # [please run cipux_setup_ldap_objects!]
$test++;

# 31
print "# [$test]: is the role object teacher   there? => ";
exit(1) if not ok($roleslist{teacher}); # [please run cipux_setup_ldap_objects!]
$test++;

# 32
print "# [$test]: is the role object student   there? => ";
exit(1) if not ok($roleslist{student}); # [please run cipux_setup_ldap_objects!]
$test++;

# 33
print "# [$test]: is the role object guest     there? => ";
exit(1) if not ok($roleslist{guest}); # [please run cipux_setup_ldap_objects!]
$test++;

# 34
print "# [$test]: is the role object examinee  there? => ";
exit(1) if not ok($roleslist{examinee}); # [please run cipux_setup_ldap_objects!]
$test++;

# 35
print "# [$test]: is the role object tutor     there? => ";
exit(1) if not ok($roleslist{tutor}); # [please run cipux_setup_ldap_objects!]
$test++;

# 36
print "# [$test]: is the role object none      there? => ";
exit(1) if not ok($roleslist{none}); # [please run cipux_setup_ldap_objects!]
$test++;


# 37
print "# [$test]: is the CipUX Configuration there? => ";
my $cipux_producer=`cipux_get_value -x CAT -e cipuxVariable|grep Cipux_Producer`;
chomp($cipux_producer);
$cipux_producer =~s/Cipux_Producer=//g;
exit(1) if not ok($cipux_producer eq "www.cipworx.org");# [The CipUX Configuration LDAP nodes are missing!]
$test++;

exit(0);

=pod

=head1 NAME

cipux_main_diagnostic - Version <[CIBOT::VERSION]>  2005-08-12 CipUX

=head1 SYNOPSIS

  cipux_main_diagnostic

=head1 ABSTRACT

This script runs several tests against  Test.pm and tries to
check if the CipUX installation is ok.

=head1 REQUIREMENTS

  CipUX::CiBot
  CipUX::Task
  CipUX::Conversion
  CipUX::Cat

=head1 SEE ALSO

See the CipUX webpage and the  manual at L<http://www.cipux.org>
See the mailing list L<http://www.cipux.org/mailman/listinfo/>

=head1 AUTHOR

Christian Kuelker  E<lt>christian.kuelker@cipworx.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright (C) 1999-2005 by Christian Kuelker

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License as
published by the Free Software Foundation; either version 2, or (at
your option) any later version.

This program is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
02111-1307 USA

=cut
