#!/usr/bin/perl -w
# +======================================================================+
# || cipux_setup_ldap_machines                                          ||
# ||                                                                    ||
# || This script moves the LDAP ou=Machines,ou=People, ... one level    ||
# || up to ou=Machines.                                                 ||
# ||                                                                    ||
# ||                                                                    ||
# || (c) 2005 by Christian Kuelker                                      ||
# ||                                                                    ||
# || License: GPLv2 (GPL version 2 or later)                            ||
# ||                                                                    ||
# +======================================================================+

=pod

=head1 NAME

cipux_setup_ldap_machines - Version <[CIBOT::VERSION]>  2005-08-01 CipUX

=head1 SYNOPSIS

	cipux_setup_ldap_machines is NOT to be used directly

=head1 ABSTRACT

This script is part of the setup process. I deletes

  ou=Machines,ou=People,dc=skole,dc=skolelinux,dc=no

with all the sub entries under ou=Machines and moves it to

  ou=Machines,dc=skole,dc=skolelinux,dc=no


=head1 REQUIREMENTS

  /etc/cipux/cipux.conf

=cut

# get the password
my $password = `grep Ldap_Password /etc/cipux/cipux.conf`;
chomp($password);
$password =~ s/ //g;
$password =~ s/Ldap_Password=//g;

&usage if not defined($password);
&usage if $password eq "secret";

print "="x76;
print "\nmigrates Skolelinux (sarge)  Machines  from\n";
print "ou=Machines,ou=People,dc=skole,dc=skolelinux,dc=no\n";
print "                     to\n";
print "ou=Machines,dc=skole,dc=skolelinux,dc=no\n";
print "="x76;
print "\n";

if($password eq ""){
  print "ERROR: please define a password in this script!\n";
  exit(1);
}

my @ldif = `/usr/bin/ldapsearch -x -p 389 -h localhost -w '$password' -ZZ  -D 'cn=admin,ou=People,dc=skole,dc=skolelinux,dc=no' -b 'ou=Machines,ou=People,dc=skole,dc=skolelinux,dc=no' -LLL`;

if($#ldif <0){# no ou=Machines any more ...
  push(@ldif,"dn: ou=Machines,dc=skole,dc=skolelinux,dc=no\n");
  push(@ldif,"objectClass: top\n");
  push(@ldif,"objectClass: organizationalUnit\n");
  push(@ldif,"ou: Machines\n");
}

foreach (@ldif){
  print "LDIF: $_";
}

# calc the dn to be deleted
foreach my $line (@ldif){
  print $line;
  if($line =~ m/^dn:(.+)/){
    push(@del,$1);
  }
}

my $obj = $#del;
$obj++;
print "* delete $obj objects ...";

# do it in reverse order
@rdel = reverse @del;
foreach my $obj (@rdel){
  print "DELETE: [$obj]\n";
  my $cmd ="/usr/bin/ldapdelete -x -p 389 -h localhost -w '$password' -ZZ  -D 'cn=admin,ou=People,dc=skole,dc=skolelinux,dc=no' $obj";
 print "CMD [$cmd]\n";
 `$cmd`;
}

# so calc the new dn now
foreach my $line (@ldif){
  print $line;
  $line =~s/ou=People,//g;
  print $line;
}

# add the objects
my $cmd = "| /usr/bin/ldapadd  -x -p 389 -h localhost -w '$password' -ZZ  -D 'cn=admin,ou=People,dc=skole,dc=skolelinux,dc=no' ";
open(CMD,$cmd) or die "can't execute command: [$cmd]";
foreach my $line (@ldif){
  print CMD $line;
}
close(CMD);

exit(0);

sub usage{
  print "="x76 . "\n";
  print "ERROR: The Ldap_Password of /etc/cipux/cipux.conf can't be extracted!\n";
  print "Please edit /etc/cipux/cipux.conf and the line Ldap_Password=secret\n";
  print "Change 'secret' to your LDAP/root password!\n";
  print "="x76 . "\n";

}

#===========================================================================
#==== Documentation ========================================================
#===========================================================================


=head1 SEE ALSO

See the CipUX webpage and the  manual at L<http://www.cipux.org>
See the mailing list L<http://www.cipux.org/mailman/listinfo/>

=head1 AUTHOR

Christian Kuelker  E<lt>christian.kuelker@cipworx.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright (C) 1999-2005 by Christian Kuelker

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License as
published by the Free Software Foundation; either version 2, or (at
your option) any later version.

This program is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
02111-1307 USA

=cut
